**********
Installing
**********

``sunkit_magex`` can be installed from PyPI using

.. code:: shell

    pip install sunkit-magex

This will install sunkit_magex and all of its dependencies.
In addition to the core dependencies, there are two optional dependencies (numba, streamtracer) that can improve code performance.
These can be installed with

.. code:: shell

    pip install sunkit-magex[performance]
